pyramid_deform
==============

``pyramid_deform`` provides bindings for the Pyramid web framework to the
`Deform <http://docs.pylonsproject.org/projects/deform>`_ form
library.

For more information, see `the documentation
<http://docs.pylonsproject.org/projects/pyramid_deform>`_.
